@@ -28,7 +28,7 @@ pub struct Command<'a> {
 /// Using a parser configured with the commands `"echo"` and `"ping"` and the
 /// prefix `"!"`, parse the message "!echo foo bar baz":
 ///
-/// ```rust
+/// ```
 /// use twilight_command_parser::{Command, CommandParserConfig, Parser};
 ///
 /// let mut config = CommandParserConfig::new();
@@ -97,7 +97,7 @@ impl<'a> Parser<'a> {
     ///
     /// # Example
     ///
-    /// ```rust
+    /// ```
     /// # use twilight_command_parser::{Command, CommandParserConfig, Parser};
     /// # fn example() -> Option<()> {
     /// let mut config = CommandParserConfig::new();
@@ -184,9 +184,8 @@ mod tests {
     #[test]
     fn double_command() {
         let parser = simple_config();
-        if parser.parse("!echoecho").is_some() {
-            panic!("Double match!");
-        }
+
+        assert!(parser.parse("!echoecho").is_none(), "double match");
     }
 
     #[test]
